@@ -1,5 +1,4 @@
-require 'backports'
-require_relative 'spec_helper'
+require 'spec_helper'
 
 describe Sinatra::Cookies do
   def cookie_route(*cookies, &block)
@@ -9,7 +8,7 @@ describe Sinatra::Cookies do
       result = instance_eval(&block)
       "ok"
     end
-    get '/'
+    get '/', {}, @headers || {}
     last_response.should be_ok
     body.should be == "ok"
     result
@@ -33,7 +32,7 @@ describe Sinatra::Cookies do
     it 'runs the block' do
       ran = false
       cookie_route { ran = true }
-      ran.should be_true
+      ran.should be true
     end
 
     it 'returns the block result' do
@@ -97,6 +96,14 @@ describe Sinatra::Cookies do
       end.should include('HttpOnly')
     end
 
+    it 'sets domain to nil if localhost' do
+      @headers = {'HTTP_HOST' => 'localhost'}
+      cookie_route do
+        cookies['foo'] = 'bar'
+        response['Set-Cookie']
+      end.should_not include("domain")
+    end
+
     it 'sets the domain' do
       cookie_route do
         cookies['foo'] = 'bar'
@@ -275,7 +282,7 @@ describe Sinatra::Cookies do
         cookies.each do |key, value|
           key.should   == 'foo'
           value.should == 'baz'
-          seen.should  == false
+          seen.should == false
           seen = true
         end
       end
@@ -435,7 +442,7 @@ describe Sinatra::Cookies do
       cookie_route do
         cookies['foo'] = 'bar'
         cookies.empty?
-      end.should be_false
+      end.should be false
     end
 
     it 'becomes true if response cookies are removed' do
@@ -443,14 +450,14 @@ describe Sinatra::Cookies do
         cookies['foo'] = 'bar'
         cookies.delete :foo
         cookies.empty?
-      end.should be_true
+      end.should be true
     end
 
     it 'becomes true if request cookies are removed' do
       cookie_route('foo=bar') do
         cookies.delete :foo
         cookies.empty?
-      end.should be_true
+      end.should be_truthy
     end
 
     it 'becomes true after clear' do
@@ -458,7 +465,7 @@ describe Sinatra::Cookies do
         cookies['foo'] = 'bar'
         cookies.clear
         cookies.empty?
-      end.should be_true
+      end.should be_truthy
     end
   end
 
@@ -595,19 +602,19 @@ describe Sinatra::Cookies do
 
   describe :key? do
     it 'checks request cookies' do
-      cookies('foo=bar').key?('foo').should be_true
+      cookies('foo=bar').key?('foo').should be true
     end
 
     it 'checks response cookies' do
       jar = cookies
       jar['foo'] = 'bar'
-      jar.key?(:foo).should be_true
+      jar.key?(:foo).should be true
     end
 
     it 'does not use deleted cookies' do
       jar = cookies('foo=bar')
       jar.delete :foo
-      jar.key?('foo').should be_false
+      jar.key?('foo').should be false
     end
   end
 
@@ -622,19 +629,19 @@ describe Sinatra::Cookies do
 
   describe :member? do
     it 'checks request cookies' do
-      cookies('foo=bar').member?('foo').should be_true
+      cookies('foo=bar').member?('foo').should be true
     end
 
     it 'checks response cookies' do
       jar = cookies
       jar['foo'] = 'bar'
-      jar.member?(:foo).should be_true
+      jar.member?(:foo).should be true
     end
 
     it 'does not use deleted cookies' do
       jar = cookies('foo=bar')
       jar.delete :foo
-      jar.member?('foo').should be_false
+      jar.member?('foo').should be false
     end
   end
 
@@ -776,19 +783,19 @@ describe Sinatra::Cookies do
 
   describe :value? do
     it 'checks request cookies' do
-      cookies('foo=bar').value?('bar').should be_true
+      cookies('foo=bar').value?('bar').should be true
     end
 
     it 'checks response cookies' do
       jar = cookies
       jar[:foo] = 'bar'
-      jar.value?('bar').should be_true
+      jar.value?('bar').should be true
     end
 
     it 'does not use deleted cookies' do
       jar = cookies('foo=bar')
       jar.delete :foo
-      jar.value?('bar').should_not be_true
+      jar.value?('bar').should be false
     end
   end
 
